@@ -1,7 +1,8 @@
 ## File Name: mice.impute.eap.R
-## File Version: 2.06
+## File Version: 2.07
 
-mice.impute.eap <- function (y, ry, x, eap, ...){
+mice.impute.eap <- function (y, ry, x, eap, ...)
+{
     pos <- parent.frame(n=1)
     res <- mice_imputation_get_states(pos=pos)
     vname <- res$vname
@@ -10,7 +11,5 @@ mice.impute.eap <- function (y, ry, x, eap, ...){
     SE.scale <- eap[[ vname ]][[ "SE" ]]
     N <- length(M.scale)
     ximp <- stats::rnorm( N, mean=M.scale, sd=SE.scale )
-    utils::flush.console()
-    # return imputed values
     return(ximp)
 }
